@@ -1,7 +1,7 @@
 from importlib.machinery import SourceFileLoader
 from pathlib import Path
 
-from aoc_core_cli import BaseRunner
+from aoc_cli_core import BaseRunner
 
 class Runner(BaseRunner):
     def __init__(self, part: int, location: Path=None):
